@@ -129,7 +129,7 @@ void SlideContainerAutoTest::testHiddenContentResize()
     // Resizing content should not trigger a slide if it is not visible.
     TestWindow window;
     window.show();
-    QTest::qWaitForWindowExposed(&window);
+    QVERIFY(QTest::qWaitForWindowExposed(&window));
 
     window.mContent->show();
     window.mContent->setFixedSize(150, 80);
