@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -59,7 +59,9 @@ public:
         q->connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
 
         lay->addWidget(buttonBox);
-        q->connect(editor, &InsertHtmlEditor::textChanged, q, [this]() {_k_slotTextChanged(); });
+        q->connect(editor, &InsertHtmlEditor::textChanged, q, [this]() {
+                _k_slotTextChanged();
+            });
         okButton->setEnabled(false);
         q->resize(640, 480);
     }
