@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,7 +31,7 @@
 
 using namespace KPIMTextEdit;
 
-class KPIMTextEdit::TextGoToLineWidgetPrivate
+class Q_DECL_HIDDEN KPIMTextEdit::TextGoToLineWidgetPrivate
 {
 public:
     TextGoToLineWidgetPrivate()
